@@ -109,7 +109,7 @@ get_CRU_stack <-
       stop("You must select at least one element for download.")
     }
 
-    cache_dir <- .set_cache()
+    cache_dir <- .set_cache(cache)
 
     files <- .get_CRU(pre,
                       pre_cv,
