@@ -59,29 +59,42 @@
 #' @rdname manage_CRU_cache
 CRU_cache_list <- function() {
   cache_dir <- rappdirs::user_cache_dir("getCRUCLdata")
-  list.files(cache_dir, ignore.case = TRUE, include.dirs = TRUE,
-             recursive = TRUE, full.names = TRUE)
+  list.files(
+    cache_dir,
+    ignore.case = TRUE,
+    include.dirs = TRUE,
+    recursive = TRUE,
+    full.names = TRUE
+  )
 }
 
 #' @export
 #' @rdname manage_CRU_cache
 CRU_cache_delete <- function(files, force = TRUE) {
   cache_dir <- rappdirs::user_cache_dir("getCRUCLdata")
-  if (!all(file.exists(cache_dir, "/", files))) {
-    stop("These files don't exist or can't be found: \n",
-         strwrap(file.path(cache_dir, files)[!file.exists(
-           file.path(cache_dir, files))], indent = 5), call. = FALSE)
+  files <- file.path(cache_dir, files)
+  if (!all(file.exists(files))) {
+    stop(
+      "These files don't exist or can't be found: \n",
+      strwrap(file.path(files)[!file.exists(files)], indent = 5),
+      call. = FALSE
+    )
   }
-  unlink(file.path(cache_dir, files),
-         force = force, recursive = TRUE)
+  unlink(files, force = force, recursive = TRUE)
 }
 
 #' @export
 #' @rdname manage_CRU_cache
 CRU_cache_delete_all <- function(force = TRUE) {
   cache_dir <- rappdirs::user_cache_dir("getCRUCLdata")
-  files <- list.files(cache_dir, ignore.case = TRUE, include.dirs = TRUE,
-                      full.names = TRUE, recursive = TRUE)
+  files <-
+    list.files(
+      cache_dir,
+      ignore.case = TRUE,
+      include.dirs = TRUE,
+      full.names = TRUE,
+      recursive = TRUE
+    )
   unlink(files, force = force, recursive = TRUE)
 }
 
@@ -90,8 +103,14 @@ CRU_cache_delete_all <- function(force = TRUE) {
 CRU_cache_details <- function(files = NULL) {
   cache_dir <- rappdirs::user_cache_dir("getCRUCLdata")
   if (is.null(files)) {
-    files <- list.files(cache_dir, ignore.case = TRUE, include.dirs = TRUE,
-                        full.names = TRUE, recursive = TRUE)
+    files <-
+      list.files(
+        cache_dir,
+        ignore.case = TRUE,
+        include.dirs = TRUE,
+        full.names = TRUE,
+        recursive = TRUE
+      )
     structure(lapply(files, file_info_), class = "CRU_cache_info")
   } else {
     structure(lapply(files, file_info_), class = "CRU_cache_info")
@@ -107,8 +126,10 @@ file_info_ <- function(x) {
   }
   list(file = x,
        type = "gz",
-       size = if (!is.na(fs)) getsize(fs) else NA
-  )
+       size = if (!is.na(fs))
+         getsize(fs)
+       else
+         NA)
 }
 
 getsize <- function(x) {
@@ -122,8 +143,11 @@ print.CRU_cache_info <- function(x, ...) {
   cat(sprintf("  directory: %s\n", cache_dir), sep = "\n")
   for (i in seq_along(x)) {
     cat(paste0("  file: ", sub(cache_dir, "", x[[i]]$file)), sep = "\n")
-    cat(paste0("  size: ", x[[i]]$size, if (is.na(x[[i]]$size)) "" else " mb"),
-        sep = "\n")
+    cat(paste0("  size: ", x[[i]]$size, if (is.na(x[[i]]$size))
+      ""
+      else
+        " mb"),
+      sep = "\n")
     cat("\n")
   }
 }
