@@ -15,6 +15,12 @@ test_that("create_CRU_df fails if no dsn is specified", {
                "File directory does not exist: .")
 })
 
+# Test that create_CRU_df fails if dsn does not contain CRU files --------------
+
+test_that("create_CRU_df fails if dsn does not contain CRU files", {
+  expect_error(create_CRU_df(pre = TRUE, dsn = "/dev/null"))
+})
+
 # Test that create_CRU_df loads files and creates a proper tibble --------------
 
 test_that("create_CRU_df loads files and creates a proper tibble", {
