@@ -8,9 +8,19 @@ test_that("get_CRU_df fails if no parameters are TRUE", {
                "You must select at least one element for download.")
 })
 
-# Test that create_CRU_df lists only .dat.gz files in the given dsn ------------
+# Test that get_CRU_df will retrieve files from CRU FTP server
+test_that("get_CRU_df will retreive files from CRU FTP server", {
 
-test_that("create_CRU_df lists only .dat.gz files in the given dsn", {
+  skip_on_cran()
+
+  rm(CRU_tmp)
+  CRU_tmp <- get_CRU_df(tmp = TRUE, tmn = FALSE, tmx = FALSE, cache = FALSE)
+  expect_is(CRU_tmp, "tbl_df")
+})
+
+# Test that get_CRU_df lists only .dat.gz files in the given dsn ------------
+
+test_that("get_CRU_df lists only .dat.gz files in the given dsn", {
   # create files for testing, these data are the first 10 lines of pre and tmp
   # from the CRU CL v. 2.0 data
 
@@ -489,7 +499,7 @@ test_that("create_CRU_df lists only .dat.gz files in the given dsn", {
     list.files(tempdir(), pattern = ".dat.gz$", full.names = TRUE)
 
   expect_type(files, "character")
-  expect_equal(files, paste0(tempdir(), "/grid_10min_tmp.dat.gz"))
+  expect_equal(files, file.path(tempdir(), "grid_10min_tmp.dat.gz"))
 })
 
 # Test that get_CRU_df sets the cache directory properly when cache is TRUE ----
